% Perform a temporal stability anaylsis for all the dispersion relations
% (c) Matthew Juniper 2013

clear
clc

% Create a cell array containing the names of the disp. rels to check
scheme{1} = 'single';
scheme{2} = 'unconf_jetwake_sin';
scheme{3} = 'unconf_jetwake_var';
scheme{4} = 'conf_jetwake_sin';
scheme{5} = 'conf_jetwake_var';

% Input the parameters
param.L = 0.9;
param.S = 1;
param.Sig = 1;
param.h = 2;

% Set the sampling values of the wavenumber, k
k = [0:0.01:2.5]';

% Set figure defaults
set(gcf,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','.|o|s|+|x')

% Open the figure
figure(1);clf
subplot(1,1,1)
cla; hold all; set(gca,'FontSize',20,'FontName','Times')
xlabel('wavenumber, $k$','Interpreter','Latex')
ylabel('growth rate, $\omega_i$','Interpreter','Latex')
title([' '...
        '  $\Lambda = ',num2str(param.L), ...
        '$, $S = ',num2str(param.S), ...
        '$, $\Sigma = ',num2str(param.Sig), ...
        '$, $h = ',num2str(param.h), ...
        '$'],'Interpreter','Latex')

% Plot the symbols
for nn = 1:length(scheme)
    % Set the dispersion relation
    param.scheme = scheme{nn};
    % Evaluate the phase velocity
    [c1,c2] = fun_eval_c(param,k);
    % Evaluate the growth rates
    w1 = c1.*k; w2 = c2.*k;
    % Plot the first eigenvalue on the same chart
    plot(k(1:20:end),imag(w1(1:20:end)),'MarkerSize',6);
end

% Plot the lines
for nn = 1:length(scheme)
    % Set the dispersion relation
    param.scheme = scheme{nn};
    % Evaluate the phase velocity
    [c1,c2] = fun_eval_c(param,k);
    % Evaluate the growth rates
    w1 = c1.*k; w2 = c2.*k;
    % Plot the first eigenvalue on the same chart
    plot(k,imag(w1),'k-');
end

han = legend(scheme);
set(han,'Interpreter','none')

% print -deps2 'script_temporal_002.eps'
